==> ToolChain_STM32_1.0.38.tar.bz: ToolChain_STM32_1.0.38/ToolChain/install_21_ExampleThreading.sh <==
#!/bin/bash

#
#  Install script for Fixpoint Mathematical Library 
#  URL: http://code.google.com/p/fixpointlib/
#
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="600_example_threading"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

  Name="${INSTALLPATH}_queues" #{ 
  createExtensionMakefileHead ${Name} #{
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_$Name

INCLUDE_DIRS += -I additionals/examples/
vpath %.c additionals/examples/

MAIN_OBJS += example_threading_queues.o

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  
  File="../extensions/activate.${Name}_lcd.sh" #{
  createActivateScriptHead $File $0 "Examples of using Multitasking: Thread-synchronization/ -communication via Queues for boards with LCD-screen"

  cat <<END_OF_ACTIVATE >>$File #{

rm 2>/dev/null \$Dir_ExtensionsActive/makefile.600_example_*
createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET

# activate.400_lcd_320x240_olimex.sh QUIET
# activate.100_board_olimex_lcd.sh QUIET
activate.250_stm_std_peripherals__rcc.sh QUIET
activate.250_stm_std_peripherals__gpio.sh QUIET
activate.250_stm_std_peripherals__fsmc.sh QUIET

END_OF_ACTIVATE
#}
  
  createActivateScriptTail $File $Name
  #}
  File="../extensions/activate.${Name}_led.sh" #{
  createActivateScriptHead $File $0 "Examples of using Multitasking: Thread-synchronization/ -communication via Queues for boards with LEDs"
  echo 'rm 2>/dev/null $Dir_ExtensionsActive/makefile.600_example_*' >>$File

  # create links into extensions.active/
  #X ../scripts/printBaseExtensions.sh >>$File
  cat <<END_OF_ACTIVATE >>$File #{
rm 2>/dev/null \$Dir_ExtensionsActive/makefile.600_example_*

activate.600_example_leds.sh QUIET
activate.250_stm_std_peripherals__rcc.sh QUIET
activate.250_stm_std_peripherals__gpio.sh QUIET

createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET

END_OF_ACTIVATE
#}
  createActivateScriptTail $File $Name
  #}

#}queues
  Name="${INSTALLPATH}_semaphores" #{ 
  createExtensionMakefileHead ${Name} #{
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_$Name
COMPILE_OPTS += -DconfigUSE_COUNTING_SEMAPHORES
COMPILE_OPTS += -DconfigUSE_MUTEXES

INCLUDE_DIRS += -I additionals/examples/
vpath %.c additionals/examples/

MAIN_OBJS += example_threading_semaphores.o

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}

  File="../extensions/activate.${Name}_lcd.sh" #{
  createActivateScriptHead $File $0 "Examples of using Multitasking: Thread-synchronization/ -communication via Semaphores for boards with LCD-screen"
  echo 'rm 2>/dev/null $Dir_ExtensionsActive/makefile.600_example_*' >>$File
  
  # create links into extensions.active/
  #X ../scripts/printBaseExtensions.sh >>$File
  cat <<END_OF_ACTIVATE >>$File #{

# activate.400_lcd_320x240_olimex.sh QUIET
# activate.100_board_olimex_lcd.sh QUIET
activate.250_stm_std_peripherals__rcc.sh QUIET
activate.250_stm_std_peripherals__gpio.sh QUIET
activate.250_stm_std_peripherals__fsmc.sh QUIET

rm 2>/dev/null \$Dir_ExtensionsActive/makefile.600_example_*
createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET

END_OF_ACTIVATE
#}
  createActivateScriptTail $File $Name
  #}
  File="../extensions/activate.${Name}_led.sh" #{
  createActivateScriptHead $File $0 "Examples of using Multitasking: Thread-synchronization/ -communication via Semaphores for boards with LEDs"
  echo 'rm 2>/dev/null $Dir_ExtensionsActive/makefile.600_example_*' >>$File
  
  # create links into extensions.active/
  #X ../scripts/printBaseExtensions.sh >>$File
  cat <<END_OF_ACTIVATE >>$File #{
createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET
activate.600_example_leds.sh QUIET
activate.250_stm_std_peripherals__rcc.sh QUIET
activate.250_stm_std_peripherals__gpio.sh QUIET
END_OF_ACTIVATE
#}

  echo "createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET" >>$File
  
  createActivateScriptTail $File $Name
  #}
  
#}semaphores
  echo "Installed successfully: $INSTALLPATH"

cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0

==> ToolChain_STM32_1.0.39.tar.bz: ToolChain_STM32_1.0.39/ToolChain/install_21_ExampleThreading.sh <==
#!/bin/bash

#
#  Install script for Fixpoint Mathematical Library 
#  URL: http://code.google.com/p/fixpointlib/
#
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="600_example_threading"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

  Name="${INSTALLPATH}_queues" #{ 
  createExtensionMakefileHead ${Name} #{
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_${Name}=1

INCLUDE_DIRS += -I additionals/examples/
vpath %.c additionals/examples/

MAIN_OBJS += example_threading_queues.o

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  
  File="../extensions/activate.${Name}_lcd.sh" #{
  createActivateScriptHead $File $0 "Examples of using Multitasking: Thread-synchronization/ -communication via Queues for boards with LCD-screen"

  cat <<END_OF_ACTIVATE >>$File #{

rm 2>/dev/null \$Dir_ExtensionsActive/makefile.600_example_*
createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET

# activate.400_lcd_320x240_olimex.sh QUIET
# activate.100_board_olimex_lcd.sh QUIET
activate.250_stm_std_peripherals__rcc.sh QUIET
activate.250_stm_std_peripherals__gpio.sh QUIET
activate.250_stm_std_peripherals__fsmc.sh QUIET

END_OF_ACTIVATE
#}
  
  createActivateScriptTail $File $Name
  #}
  File="../extensions/activate.${Name}_led.sh" #{
  createActivateScriptHead $File $0 "Examples of using Multitasking: Thread-synchronization/ -communication via Queues for boards with LEDs"
  echo 'rm 2>/dev/null $Dir_ExtensionsActive/makefile.600_example_*' >>$File

  # create links into extensions.active/
  #X ../scripts/printBaseExtensions.sh >>$File
  cat <<END_OF_ACTIVATE >>$File #{
rm 2>/dev/null \$Dir_ExtensionsActive/makefile.600_example_*

activate.600_example_leds.sh QUIET
activate.250_stm_std_peripherals__rcc.sh QUIET
activate.250_stm_std_peripherals__gpio.sh QUIET

createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET

END_OF_ACTIVATE
#}
  createActivateScriptTail $File $Name
  #}

#}queues
  Name="${INSTALLPATH}_semaphores" #{ 
  createExtensionMakefileHead ${Name} #{
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_${Name}=1
COMPILE_OPTS += -DconfigUSE_COUNTING_SEMAPHORES
COMPILE_OPTS += -DconfigUSE_MUTEXES

INCLUDE_DIRS += -I additionals/examples/
vpath %.c additionals/examples/

MAIN_OBJS += example_threading_semaphores.o

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}

  File="../extensions/activate.${Name}_lcd.sh" #{
  createActivateScriptHead $File $0 "Examples of using Multitasking: Thread-synchronization/ -communication via Semaphores for boards with LCD-screen"
  echo 'rm 2>/dev/null $Dir_ExtensionsActive/makefile.600_example_*' >>$File
  
  # create links into extensions.active/
  #X ../scripts/printBaseExtensions.sh >>$File
  cat <<END_OF_ACTIVATE >>$File #{

# activate.400_lcd_320x240_olimex.sh QUIET
# activate.100_board_olimex_lcd.sh QUIET
activate.250_stm_std_peripherals__rcc.sh QUIET
activate.250_stm_std_peripherals__gpio.sh QUIET
activate.250_stm_std_peripherals__fsmc.sh QUIET

rm 2>/dev/null \$Dir_ExtensionsActive/makefile.600_example_*
createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET

END_OF_ACTIVATE
#}
  createActivateScriptTail $File $Name
  #}
  File="../extensions/activate.${Name}_led.sh" #{
  createActivateScriptHead $File $0 "Examples of using Multitasking: Thread-synchronization/ -communication via Semaphores for boards with LEDs"
  echo 'rm 2>/dev/null $Dir_ExtensionsActive/makefile.600_example_*' >>$File
  
  # create links into extensions.active/
  #X ../scripts/printBaseExtensions.sh >>$File
  cat <<END_OF_ACTIVATE >>$File #{
createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET
activate.600_example_leds.sh QUIET
activate.250_stm_std_peripherals__rcc.sh QUIET
activate.250_stm_std_peripherals__gpio.sh QUIET
END_OF_ACTIVATE
#}

  echo "createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET" >>$File
  
  createActivateScriptTail $File $Name
  #}
  
#}semaphores
  echo "Installed successfully: $INSTALLPATH"

cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0
